@@ -161,6 +161,8 @@ AMPHORA_ALLOCATED = lib_consts.AMPHORA_ALLOCATED
 AMPHORA_BOOTING = lib_consts.AMPHORA_BOOTING
 # Amphora is ready to be allocated to a load balancer 'READY'
 AMPHORA_READY = lib_consts.AMPHORA_READY
+# 'FAILOVER_STOPPED'. Failover threshold level has been reached.
+AMPHORA_FAILOVER_STOPPED = lib_consts.AMPHORA_FAILOVER_STOPPED
 # 'ACTIVE'
 ACTIVE = lib_consts.ACTIVE
 # 'PENDING_DELETE'
@@ -248,13 +250,6 @@ MUTABLE_STATUSES = (lib_consts.ACTIVE,)
 DELETABLE_STATUSES = (lib_consts.ACTIVE, lib_consts.ERROR)
 FAILOVERABLE_STATUSES = (lib_consts.ACTIVE, lib_consts.ERROR)
 
-# Note: The database Amphora table has a foreign key constraint against
-#       the provisioning_status table
-SUPPORTED_AMPHORA_STATUSES = (
-    lib_consts.AMPHORA_ALLOCATED, lib_consts.AMPHORA_BOOTING, lib_consts.ERROR,
-    lib_consts.AMPHORA_READY, lib_consts.DELETED, lib_consts.PENDING_CREATE,
-    lib_consts.PENDING_DELETE)
-
 AMPHORA_VM = 'VM'
 SUPPORTED_AMPHORA_TYPES = (AMPHORA_VM,)
 
@@ -296,12 +291,16 @@ DOMAIN_NAME_REGEX = (
     r'^(?=.{1,253}\.?$)(?:(?!-|[^.]+_)[A-Za-z0-9-_]{1,63}(?<!-)(?:\.|$))+$')
 
 # TaskFlow
-SUPPORTED_TASKFLOW_ENGINE_TYPES = ['serial', 'parallel']
+SUPPORTED_TASKFLOW_ENGINE_TYPES = [
+    ('serial', 'Runs all tasks on a single thread'),
+    ('parallel', 'Schedules tasks onto different threads to allow for running '
+                 'non-dependent tasks simultaneously')]
 
 # Task/Flow constants
 ACTIVE_CONNECTIONS = 'active_connections'
 ADD_NICS = 'add_nics'
 ADD_SUBNETS = 'add_subnets'
+ADDITIONAL_VIPS = 'additional_vips'
 ADMIN_STATE_UP = 'admin_state_up'
 ALLOWED_ADDRESS_PAIRS = 'allowed_address_pairs'
 AMP_DATA = 'amp_data'
@@ -313,7 +312,6 @@ AMPHORA_INDEX = 'amphora_index'
 AMPHORA_NETWORK_CONFIG = 'amphora_network_config'
 AMPHORAE = 'amphorae'
 AMPHORAE_NETWORK_CONFIG = 'amphorae_network_config'
-AMPHORAE_STATUS = 'amphorae_status'
 AMPS_DATA = 'amps_data'
 ANTI_AFFINITY = 'anti-affinity'
 ATTEMPT_NUMBER = 'attempt_number'
@@ -385,7 +383,6 @@ MESSAGE = 'message'
 NAME = 'name'
 NETWORK = 'network'
 NETWORK_ID = 'network_id'
-NEW_AMPHORA_ID = 'new_amphora_id'
 NEXTHOP = 'nexthop'
 NICS = 'nics'
 OBJECT = 'object'
@@ -432,7 +429,6 @@ TLS_CERTIFICATE_ID = 'tls_certificate_id'
 TLS_CONTAINER_ID = 'tls_container_id'
 TOPOLOGY = 'topology'
 TOTAL_CONNECTIONS = 'total_connections'
-UNREACHABLE = 'unreachable'
 UPDATED_AT = 'updated_at'
 UPDATE_DICT = 'update_dict'
 UPDATED_PORTS = 'updated_ports'
@@ -560,7 +556,6 @@ ADMIN_DOWN_PORT = 'admin-down-port'
 AMPHORA_POST_VIP_PLUG = 'amphora-post-vip-plug'
 AMPHORA_RELOAD_LISTENER = 'amphora-reload-listener'
 AMPHORA_TO_ERROR_ON_REVERT = 'amphora-to-error-on-revert'
-AMPHORAE_GET_CONNECTIVITY_STATUS = 'amphorae-get-connectivity-status'
 AMPHORAE_POST_NETWORK_PLUG = 'amphorae-post-network-plug'
 ATTACH_PORT = 'attach-port'
 CALCULATE_AMPHORA_DELTA = 'calculate-amphora-delta'
@@ -797,6 +792,7 @@ RBAC_ROLES_DEPRECATED_REASON = (
 # PROVIDERS
 OCTAVIA = 'octavia'
 AMPHORAV2 = 'amphorav2'
+# Deprecated in Z, to be removed
 AMPHORAV1 = 'amphorav1'
 
 # systemctl commands
@@ -913,9 +909,6 @@ AMPHORA_SUPPORTED_ALPN_PROTOCOLS = [lib_consts.ALPN_PROTOCOL_HTTP_2,
                                     lib_consts.ALPN_PROTOCOL_HTTP_1_0]
 
 # Amphora interface fields
-IF_TYPE = 'if_type'
-BACKEND = 'backend'
-LO = 'lo'
 MTU = 'mtu'
 ADDRESSES = 'addresses'
 ROUTES = 'routes'
