@@ -487,6 +487,24 @@ class TestHaproxyCfg(base.TestCase):
                 frontend=fe, backend=be, logging=logging, defaults=defaults),
             rendered_obj)
 
+    def test_render_template_additional_vips(self):
+        fe = ("frontend sample_listener_id_1\n"
+              "    maxconn {maxconn}\n"
+              "    bind 10.0.0.2:80\n"
+              "    bind 10.0.1.2:80\n"
+              "    bind 2001:db8::2:80\n"
+              "    mode http\n"
+              "    default_backend sample_pool_id_1:sample_listener_id_1\n"
+              "    timeout client 50000\n").format(
+            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+        rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
+            sample_configs_combined.sample_amphora_tuple(),
+            [sample_configs_combined.sample_listener_tuple(
+                additional_vips=True)])
+        self.assertEqual(
+            sample_configs_combined.sample_base_expected_config(frontend=fe),
+            rendered_obj)
+
     def test_render_template_member_backup(self):
         be = ("backend sample_pool_id_1:sample_listener_id_1\n"
               "    mode http\n"
@@ -668,6 +686,7 @@ class TestHaproxyCfg(base.TestCase):
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
               "    timeout check 31s\n"
+              "    option ssl-hello-chk\n"
               "    fullconn {maxconn}\n"
               "    option allbackups\n"
               "    timeout connect 5000\n"
@@ -761,6 +780,7 @@ class TestHaproxyCfg(base.TestCase):
               "    mode http\n"
               "    balance roundrobin\n"
               "    cookie SRV insert indirect nocache\n"
+              "    load-server-state-from-file global\n"
               "    timeout check 31s\n"
               "    option external-check\n"
               "    external-check command /var/lib/octavia/ping-wrapper.sh\n"
@@ -775,14 +795,18 @@ class TestHaproxyCfg(base.TestCase):
               "weight 13 check inter 30s fall 3 rise 2 "
               "cookie sample_member_id_2\n\n").format(
             maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
-        go = (f"    maxconn {constants.HAPROXY_DEFAULT_MAXCONN}\n"
-              "    external-check\n    insecure-fork-wanted\n\n")
+        go = (
+            "    server-state-file /var/lib/octavia/sample_loadbalancer_id_1/"
+            "servers-state\n"
+            f"    maxconn {constants.HAPROXY_DEFAULT_MAXCONN}\n"
+            "    external-check\n    insecure-fork-wanted\n\n")
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_combined.sample_amphora_tuple(),
             [sample_configs_combined.sample_listener_tuple(
                 proto='HTTP', monitor_proto='PING')],
             feature_compatibility={
-                "requires_insecure_fork": True})
+                "requires_insecure_fork": True,
+                constants.SERVER_STATE_FILE: True})
         self.assertEqual(sample_configs_combined.sample_base_expected_config(
             backend=be, global_opts=go), rendered_obj)
 
@@ -1180,11 +1204,11 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout connect 5000\n"
               "    timeout server 50000\n"
               "    server sample_member_id_1 10.0.0.99:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_1 {opts} alpn {alpn}\n"
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_1 "
+              "{opts} alpn {alpn}\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_2 {opts} alpn {alpn}\n\n").format(
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_2 "
+              "{opts} alpn {alpn}\n\n").format(
             maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
             opts="ssl crt %s verify none sni ssl_fc_sni" % cert_file_path +
                  " ciphers " + constants.CIPHERS_OWASP_SUITE_B +
@@ -1259,11 +1283,11 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout connect 5000\n"
               "    timeout server 50000\n"
               "    server sample_member_id_1 10.0.0.99:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_1 {opts} alpn {alpn}\n"
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_1 "
+              "{opts} alpn {alpn}\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_2 {opts} alpn {alpn}\n\n").format(
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_2 "
+              "{opts} alpn {alpn}\n\n").format(
             maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
             opts="ssl crt %s verify none sni ssl_fc_sni" % cert_file_path +
                  " ciphers " + constants.CIPHERS_OWASP_SUITE_B,
@@ -1299,11 +1323,11 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout connect 5000\n"
               "    timeout server 50000\n"
               "    server sample_member_id_1 10.0.0.99:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_1 {opts} alpn {alpn}\n"
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_1 "
+              "{opts} alpn {alpn}\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_2 {opts} alpn {alpn}\n\n").format(
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_2 "
+              "{opts} alpn {alpn}\n\n").format(
             maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
             opts="ssl crt %s verify none sni ssl_fc_sni" % cert_file_path +
                  " no-sslv3 no-tlsv10 no-tlsv11",
@@ -1399,11 +1423,11 @@ class TestHaproxyCfg(base.TestCase):
               "    timeout connect 5000\n"
               "    timeout server 50000\n"
               "    server sample_member_id_1 10.0.0.99:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_1 {opts} alpn {alpn}\n"
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_1 "
+              "{opts} alpn {alpn}\n"
               "    server sample_member_id_2 10.0.0.98:82 weight 13 "
-              "check check-alpn {alpn} inter 30s fall 3 rise 2 cookie "
-              "sample_member_id_2 {opts} alpn {alpn}\n\n").format(
+              "check inter 30s fall 3 rise 2 cookie sample_member_id_2 "
+              "{opts} alpn {alpn}\n\n").format(
             maxconn=constants.HAPROXY_DEFAULT_MAXCONN,
             opts="%s %s %s %s %s %s" % (
                 "ssl", "crt", pool_client_cert,
@@ -1790,7 +1814,6 @@ class TestHaproxyCfg(base.TestCase):
         expected_fc = {
             constants.HTTP_REUSE: True,
             constants.SERVER_STATE_FILE: True
-
         }
         mock_render_loadbalancer_obj.assert_called_once_with(
             mock_amp, mock_listeners, tls_certs=mock_tls_certs,
@@ -1805,8 +1828,8 @@ class TestHaproxyCfg(base.TestCase):
 
         expected_fc = {
             constants.HTTP_REUSE: True,
-            constants.SERVER_STATE_FILE: True,
-            constants.POOL_ALPN: True
+            constants.POOL_ALPN: True,
+            constants.SERVER_STATE_FILE: True
         }
         mock_render_loadbalancer_obj.assert_called_once_with(
             mock_amp, mock_listeners, tls_certs=mock_tls_certs,
@@ -1821,9 +1844,9 @@ class TestHaproxyCfg(base.TestCase):
 
         expected_fc = {
             constants.HTTP_REUSE: True,
-            constants.SERVER_STATE_FILE: True,
             constants.POOL_ALPN: True,
-            lib_consts.PROTOCOL_PROMETHEUS: True
+            lib_consts.PROTOCOL_PROMETHEUS: True,
+            constants.SERVER_STATE_FILE: True
         }
         mock_render_loadbalancer_obj.assert_called_once_with(
             mock_amp, mock_listeners, tls_certs=mock_tls_certs,
@@ -1838,10 +1861,10 @@ class TestHaproxyCfg(base.TestCase):
 
         expected_fc = {
             constants.HTTP_REUSE: True,
-            constants.SERVER_STATE_FILE: True,
             constants.POOL_ALPN: True,
             lib_consts.PROTOCOL_PROMETHEUS: True,
-            constants.INSECURE_FORK: True
+            constants.INSECURE_FORK: True,
+            constants.SERVER_STATE_FILE: True
         }
         mock_render_loadbalancer_obj.assert_called_once_with(
             mock_amp, mock_listeners, tls_certs=mock_tls_certs,
