@@ -155,16 +155,10 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.UPDATE_DICT, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
-
-        self.assertIn(constants.AMPHORAE, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
-        self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
 
-        self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(4, len(amp_flow.provides))
+        self.assertEqual(2, len(amp_flow.requires))
 
         amp_flow = self.LBFlow.get_post_lb_amp_association_flow(
             '123', constants.TOPOLOGY_ACTIVE_STANDBY)
@@ -173,16 +167,10 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertIn(constants.LOADBALANCER_ID, amp_flow.requires)
         self.assertIn(constants.UPDATE_DICT, amp_flow.requires)
-        self.assertIn(constants.AMPHORA_ID, amp_flow.requires)
-
-        self.assertIn(constants.AMPHORAE, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_STATUS, amp_flow.provides)
-        self.assertIn(constants.AMPHORAE_NETWORK_CONFIG, amp_flow.provides)
-        self.assertIn(constants.AMP_VRRP_INT, amp_flow.provides)
         self.assertIn(constants.LOADBALANCER, amp_flow.provides)
 
-        self.assertEqual(5, len(amp_flow.provides))
-        self.assertEqual(3, len(amp_flow.requires))
+        self.assertEqual(4, len(amp_flow.provides))
+        self.assertEqual(2, len(amp_flow.requires))
 
     def test_get_create_load_balancer_flows_single_listeners(
             self, mock_get_net_driver):
@@ -231,7 +219,6 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.LISTENERS, create_flow.provides)
         self.assertIn(constants.AMPHORA, create_flow.provides)
         self.assertIn(constants.AMPHORA_ID, create_flow.provides)
-        self.assertIn(constants.AMPHORAE_STATUS, create_flow.provides)
         self.assertIn(constants.COMPUTE_ID, create_flow.provides)
         self.assertIn(constants.COMPUTE_OBJ, create_flow.provides)
         self.assertIn(constants.LOADBALANCER, create_flow.provides)
@@ -243,7 +230,7 @@ class TestLoadBalancerFlows(base.TestCase):
                       create_flow.provides)
 
         self.assertEqual(6, len(create_flow.requires))
-        self.assertEqual(17, len(create_flow.provides),
+        self.assertEqual(16, len(create_flow.provides),
                          create_flow.provides)
 
     def _test_get_failover_LB_flow_single(self, amphorae):
@@ -335,7 +322,6 @@ class TestLoadBalancerFlows(base.TestCase):
         self.assertIn(constants.AMPHORA, failover_flow.provides)
         self.assertIn(constants.AMPHORA_ID, failover_flow.provides)
         self.assertIn(constants.AMPHORAE, failover_flow.provides)
-        self.assertIn(constants.AMPHORAE_STATUS, failover_flow.provides)
         self.assertIn(constants.AMPHORAE_NETWORK_CONFIG,
                       failover_flow.provides)
         self.assertIn(constants.BASE_PORT, failover_flow.provides)
@@ -353,7 +339,7 @@ class TestLoadBalancerFlows(base.TestCase):
 
         self.assertEqual(6, len(failover_flow.requires),
                          failover_flow.requires)
-        self.assertEqual(17, len(failover_flow.provides),
+        self.assertEqual(16, len(failover_flow.provides),
                          failover_flow.provides)
 
     def test_get_failover_LB_flow_no_amps_act_stdby(self, mock_get_net_driver):
